==> istio-model-v1beta1-6.6.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionDelayExponentialDelayFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionDelayExponentialDelayFluentImpl<A extends HTTPFaultInjectionDelayExponentialDelayFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionDelayExponentialDelayFluent<A>{
  public HTTPFaultInjectionDelayExponentialDelayFluentImpl() {
  }
  public HTTPFaultInjectionDelayExponentialDelayFluentImpl(HTTPFaultInjectionDelayExponentialDelay instance) {
    this.withExponentialDelay(instance.getExponentialDelay()); 
  }
  private String exponentialDelay;
  public String getExponentialDelay() {
    return this.exponentialDelay;
  }
  public A withExponentialDelay(String exponentialDelay) {
    this.exponentialDelay=exponentialDelay; return (A) this;
  }
  public Boolean hasExponentialDelay() {
    return this.exponentialDelay != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPFaultInjectionDelayExponentialDelayFluentImpl that = (HTTPFaultInjectionDelayExponentialDelayFluentImpl) o;
    if (exponentialDelay != null ? !exponentialDelay.equals(that.exponentialDelay) :that.exponentialDelay != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(exponentialDelay,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (exponentialDelay != null) { sb.append("exponentialDelay:"); sb.append(exponentialDelay); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPFaultInjectionDelayExponentialDelayFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionDelayExponentialDelayFluentImpl<A extends HTTPFaultInjectionDelayExponentialDelayFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionDelayExponentialDelayFluent<A>{
  public HTTPFaultInjectionDelayExponentialDelayFluentImpl() {
  }
  public HTTPFaultInjectionDelayExponentialDelayFluentImpl(HTTPFaultInjectionDelayExponentialDelay instance) {
    if (instance != null) {
      this.withExponentialDelay(instance.getExponentialDelay());
    }
  }
  private String exponentialDelay;
  public String getExponentialDelay() {
    return this.exponentialDelay;
  }
  public A withExponentialDelay(String exponentialDelay) {
    this.exponentialDelay=exponentialDelay; return (A) this;
  }
  public Boolean hasExponentialDelay() {
    return this.exponentialDelay != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionDelayExponentialDelayFluentImpl that = (HTTPFaultInjectionDelayExponentialDelayFluentImpl) o;
    if (!java.util.Objects.equals(exponentialDelay, that.exponentialDelay)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(exponentialDelay,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (exponentialDelay != null) { sb.append("exponentialDelay:"); sb.append(exponentialDelay); }
    sb.append("}");
    return sb.toString();
  }
  
}
